brotli

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 21, 2022 License: Apache-2.0 Imports: 6 Imported by: 0

README

parquet-go-brotli

Go Reference

This library implements the Brotli compression algorithms for github.com/fraugster/parquet-go. By default, parquet-go library only supports GZIP and SNAPPY as compression algorithms to minimize the list of dependencies.

All you need to do is import this package into your program and the compression algorithm will be automatically available in parquet-go.

import (
    _ "github.com/akrennmair/parquet-go-brotli" // registers the Brotli block compressor with parquet-go
)

License

See the file LICENSE for further license information.

Author

Andreas Krennmair ak@synflood.at

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BrotliBlockCompressor

type BrotliBlockCompressor struct{}

func NewBrotliBlockCompressor

func NewBrotliBlockCompressor() *BrotliBlockCompressor

func (*BrotliBlockCompressor) CompressBlock

func (c *BrotliBlockCompressor) CompressBlock(data []byte) ([]byte, error)

func (*BrotliBlockCompressor) DecompressBlock

func (c *BrotliBlockCompressor) DecompressBlock(data []byte) ([]byte, error)

Jump to